@@ -20,6 +20,9 @@ const EXIT_CODE_FAILURE: i32 = 1;
 const SP_ALIGN: u64 = 8;
 
 fn main() -> Result<()> {
+    // clippy complains about redundant closure, but in fact
+    // the function signature isn't 100% compatible so we must wrap it
+    #[allow(clippy::redundant_closure)]
     notmain().map(|code| process::exit(code))
 }
 
@@ -32,6 +35,11 @@ fn notmain() -> Result<i32> {
     {
         let exit_status = linking::link_normally(&args)?;
         if !exit_status.success() {
+            eprintln!();
+            eprintln!(
+                "flip-link: the native linker failed to link the program normally; \
+                 please check your project configuration and linker scripts"
+            );
             return Ok(exit_status.code().unwrap_or(EXIT_CODE_FAILURE));
         }
         // if linking succeeds then linker scripts are well-formed; we'll rely on that in the parser
@@ -203,8 +211,8 @@ impl LinkerScript {
 }
 
 fn get_linker_scripts(args: &[String], current_dir: &Path) -> Result<Vec<LinkerScript>> {
-    let mut search_paths = argument_parser::get_search_paths(args);
-    search_paths.push(current_dir.into());
+    let mut search_paths = vec![current_dir.into()];
+    search_paths.extend(argument_parser::get_search_paths(args));
 
     let mut search_targets = argument_parser::get_search_targets(args);
 
@@ -317,7 +325,7 @@ fn find_ram_in_linker_script(linker_script: &str) -> Option<MemoryEntry> {
         for segment in segments {
             let boundary_pos = segment
                 .find(|c| c == 'K' || c == 'M')
-                .unwrap_or_else(|| segment.len());
+                .unwrap_or(segment.len());
             let length: u64 = tryc!(segment[..boundary_pos].parse());
             let raw = &segment[boundary_pos..];
             let mut chars = raw.chars();
